Coverage report

# Coverage report: 80%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 232 | 47 | 0 | 80%
beyonic | 9 | 0 | 0 | 100%
beyonic.api_client | 116 | 39 | 0 | 66%
beyonic.apis | 0 | 0 | 0 | 100%
beyonic.apis.abstract_api | 62 | 2 | 0 | 97%
beyonic.apis.collection | 3 | 0 | 0 | 100%
beyonic.apis.collectionrequest | 3 | 0 | 0 | 100%
beyonic.apis.payment | 3 | 0 | 0 | 100%
beyonic.apis.webhook | 3 | 0 | 0 | 100%
beyonic.errors | 4 | 0 | 0 | 100%
beyonic.resources | 29 | 6 | 0 | 79%